@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2020, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -83,3 +83,9 @@ int xopen_read(const char * path);
 int xopen_write(const char * path);
 
 const char * xstrcasestr(const char * haystack, const char * needle);
+
+#ifdef _WIN32
+FARPROC arch_dlsym(HMODULE handle, const char * symbol);
+#else
+void * arch_dlsym(void * handle, const char * symbol);
+#endif
