@@ -177,7 +177,7 @@ inline void cluster_query_core(struct searchinfo_s * si)
   /* the main core function for clustering */
 
   /* get sequence etc */
-  int seqno = si->query_no;
+  const int seqno = si->query_no;
   si->query_head_len = db_getheaderlen(seqno);
   si->query_head = db_getheader(seqno);
   si->qsize = db_getabundance(seqno);
@@ -375,13 +375,15 @@ char * relabel_otu(int clusterno, char * sequence, int seqlen)
   char * label = nullptr;
   if (opt_relabel)
     {
-      label = (char*) xmalloc(strlen(opt_relabel) + 21);
-      sprintf(label, "%s%d", opt_relabel, clusterno+1);
+      int size = strlen(opt_relabel) + 21;
+      label = (char*) xmalloc(size);
+      snprintf(label, size, "%s%d", opt_relabel, clusterno + 1);
     }
   else if (opt_relabel_self)
     {
-      label = (char*) xmalloc(seqlen + 1);
-      sprintf(label, "%.*s", seqlen, sequence);
+      int size = seqlen + 1;
+      label = (char*) xmalloc(size);
+      snprintf(label, size, "%.*s", seqlen, sequence);
     }
   else if (opt_relabel_sha1)
     {
@@ -529,11 +531,12 @@ void cluster_core_results_nohit(int clusterno,
   if (opt_uc)
     {
       fprintf(fp_uc, "S\t%d\t%d\t*\t*\t*\t*\t*\t", clusters, qseqlen);
-      header_fprint_strip_size_ee(fp_uc,
-                                  query_head,
-                                  strlen(query_head),
-                                  opt_xsize,
-                                  opt_xee);
+      header_fprint_strip(fp_uc,
+                          query_head,
+                          strlen(query_head),
+                          opt_xsize,
+                          opt_xee,
+                          opt_xlength);
       fprintf(fp_uc, "\t*\n");
     }
 
@@ -591,8 +594,8 @@ void cluster_core_parallel()
   /* create threads and set them in stand-by mode */
   threads_init();
 
-  const int queries_per_thread = 1;
-  int max_queries = queries_per_thread * opt_threads;
+  constexpr static int queries_per_thread = 1;
+  const int max_queries = queries_per_thread * opt_threads;
 
   /* allocate memory for the search information for each query;
      and initialize it */
@@ -1423,9 +1426,11 @@ void cluster(char * dbname,
   /* allocate memory for full file name of the clusters files */
   FILE * fp_clusters = nullptr;
   char * fn_clusters = nullptr;
+  int fn_clusters_size = 0;
   if (opt_clusters)
     {
-      fn_clusters = (char *) xmalloc(strlen(opt_clusters) + 25);
+      fn_clusters_size += strlen(opt_clusters) + 25;
+      fn_clusters = (char *) xmalloc(fn_clusters_size);
     }
 
   int lastcluster = -1;
@@ -1463,11 +1468,12 @@ void cluster(char * dbname,
               fprintf(fp_uc, "C\t%d\t%" PRId64 "\t*\t*\t*\t*\t*\t",
                       clusterno,
                       cluster_abundance[clusterno]);
-              header_fprint_strip_size_ee(fp_uc,
-                                          db_getheader(seqno),
-                                          db_getheaderlen(seqno),
-                                          opt_xsize,
-                                          opt_xee);
+              header_fprint_strip(fp_uc,
+                                  db_getheader(seqno),
+                                  db_getheaderlen(seqno),
+                                  opt_xsize,
+                                  opt_xee,
+                                  opt_xlength);
               fprintf(fp_uc, "\t*\n");
             }
 
@@ -1480,7 +1486,11 @@ void cluster(char * dbname,
                 }
 
               ordinal = 0;
-              sprintf(fn_clusters, "%s%d", opt_clusters, clusterno);
+              snprintf(fn_clusters,
+                       fn_clusters_size,
+                       "%s%d",
+                       opt_clusters,
+                       clusterno);
               fp_clusters = fopen_output(fn_clusters);
               if (!fp_clusters)
                 {
