@@ -159,7 +159,8 @@ void msa(FILE * fp_msaout, FILE * fp_consout, FILE * fp_profile,
 
   /* allocate memory for profile (for consensus) and aligned seq */
   profile = (prof_type *) xmalloc(PROFSIZE * sizeof(prof_type) * alnlen);
-  memset(profile, 0, PROFSIZE * sizeof(prof_type) * alnlen);
+  for (int i=0; i < PROFSIZE * alnlen; i++)
+    profile[i] = 0;
   aln = (char *) xmalloc(alnlen+1);
   char * cons = (char *) xmalloc(alnlen+1);
 
